#!/bin/sh
#
# abcparam.sh  version 2.2  define parameters for alignment by classification
#

#
# General parameters
#
# prefix of directory names of alignment cycles
export DIRPRFX="cycle-"

# prefix of output file names
export CYCPRFX="max-"

# directory with initial alignment parameters (relative to top directory)
export TRFDIR="trf"

# size of subvolumes
export MOTIFSIZE="48 48 72"

# sampling factor
export SAMPFACT="1 1 1"

# missing wedge compensation
export WDGCOMP="true"


#
# MSA parameters
#
# size of extracted subvolumes for MSA
export MSAIMGSIZE="24 24 36"

# sampling factor for subvolume extraction
export MSAIMGSMP="${SAMPFACT}"

# size of converted image, to polar or cylindrical coordinates
# use "auto" to set size automatically
# export MSAPOLSIZE="72 12 36"

# file name of MSA mask, path name is relative to DIRPRFX,
# size must be defined above with MSAIMGSIZE or MSAPOLSIZE
# (leave blank to use mask creation options below)
export MSAMASK=

# MSA mask creation options
# -mw for rectangular window, -md for ellipsoidal mask
# -mc is the mask center
export MSAMASKOPT1="-md 21 21  0 -mc 0 0 0"
export MSAMASKOPT2="-mw  0  0 43 -mc 0 0 0"
export MSAMASKOPT3=
# file name of image to superimpose mask (leave blank to skip)
export MSAMASKSUPERPOS=

# create averages of raw stack
export MSAIMGAVG="false"

# image mask applied to extracted motifs
# -mw for rectangular window, -md for ellipsoidal mask
# -ms is the mask apodization, -mc the mask center
export MSAIMGMSK="-md 45 45 0 -ms 7 7 0 -mc 0 0 0"

# Fourier space filters
# MSALOWPASS: diameter of low-pass filter mask
# MSALOWAPO:  low-pass apodization
export MSALOWPASS="0.40 0.40 0.40"
export MSALOWAPO="0.05 0.05 0.05"
# MSAHIPASS:  diameter of high-pass filter mask
# MSAHIAPO:   high-pass apodization
export MSAHIPASS="0.060 0.060 0.060"
export MSAHIAPO="0.007 0.007 0.007"
# additional filter stored in an image file (leave blank to skip)
# image size must be the corresponding transform size of MSAIMGSIZE
export MSAFILT=

# Maximal number of factors
export MSAFACT=40

# montage of eigenimages (true or false)
export MSAMONT="true"
# number of columns in montage
#export MSAMONTCOL="10"


#
# Classification parameters
#
# number of classes to generate
# (single number)
export CLASSES="8"

# factors used in classification
# (comma separated list, no spaces)
export CLSFACT="1-4"

# low-pass filter for montaged class averages (leave blank to skip montage)
export CLSMONT="0.4"
# number of columns in montage
#export CLSMONTCOL="10"


#
# Parameters for class average alignment
#
# real space masks (maximum 3, applied sequentially)
# (leave blank for no mask)
export SELMSKOPT1="-md 31 31  0 -ms 7 7 0 -mc 0.01 0.01 0.01"
export SELMSKOPT2="-mw  0  0 61 -ms 0 0 7"
export SELMSKOPT3=

# Fourier space filters
# SELLOWPASS: diameter of low-pass filter mask
# SELLOWAPO:  low-pass apodization
export SELLOWPASS="0.50 0.50 0.50"
export SELLOWAPO="0.05 0.05 0.05"
# SELHIPASS:  diameter of high-pass filter mask
# SELHIAPO:   high-pass apodization
export SELHIPASS="0.060 0.060 0.060"
export SELHIAPO="0.007 0.007 0.007"
# additional filter stored in an image file (leave blank to skip)
# image size must be the corresponding transform size of MOTIFSIZE
export SELFILT=

# cross-correlation mode: xcf mcf pcf dbl (leave blank for xcf)
export SELCC="xcf"

# montages (true or false)
export SELMONT="true"
# number of columns in montage
#export SELMONTCOL="10"

# peak search radius
export SELPKR="5 5 15"

# radius for center of mass calculation
# export SELCMR="2 2 2"

# grid search (3D)
# for translational alignment only, use "0 0 0 0"
# for rotational alignment, use "<nut> <nstep> <spin> <sstep>"
# search direction of rotation axis in concentric cones with 
# maximum half-angle <nut> (nutation angle), and angular step <nstep>
# search rotation about the above axis from -<spin> to +<spin>
# (spin angle) with step size <sstep>
# rotational alignment about z-axis only: "0 0 <spin> <sstep>"
# angular ranges: 0 <= <spin> <= 180;  0 <= <nut> <= 180
# grid search (2D)
# rotational alignment: "<rot> <step>"
# angular range: 0 <= <rot> <= 180
export SELSRCH="0 0 180 36"

# execution options
# use "nohup" to run on a single processor
# use "nohup <n>" to run on <n> processors
export SELOPT="nohup 4"


#
# Fourier shell correlation
#
# real space masks (maximum 3, applied sequentially)
# (leave blank to skip)
export FSCMSKOPT1="-md 31 31  0 -ms 7 7 0 -mc 0.01 0.01 0.01"
export FSCMSKOPT2="-mw  0  0 61 -ms 0 0 7"
export FSCMSKOPT3=


#
# miscellaneous parameters
#
# produce global average
export GLBLAVG="true"

# produce side views of averages
export YPERM="true"

# uncomment to keep large image stacks (default is delete)
# export MSAIMGKEEP="true"

# uncomment to use custom temporary file directory
# export I3TMPDIR="/tmp"

# uncomment to use custom scripts in specified directory
# export I3SCRIPTS="scripts"
