#!/bin/bash
#
# i3classavg.sh  version 2.1  compute class averages
#

set -e

# projection direction for 2d montage (x y or z), 3D case only
mont=y

# wedge compensation
unset wdgopt
if [ "w${WDGCOMP}" = wtrue -a ${DIM} = 3 ]; then
  wdgopt="-wdg -wno"
fi

# compute class sums and produce dendrograms and montages
for nc in ${CLASSES}; do
  c=$( printf '%03u' ${nc} )
  d="${CLS}-${c}"
  mkdir ${d}
  i3datalist -cls ${CLS}.i3d ${d} |
  awk -v d=${DIM} -v c=${nc} '
    { if ( d == 2 ) { m[$11]++ } else{ m[$18]++ } }
    END {
      for ( i = 0; i < c; i++ ) {
        printf( "%03u  %u\n", i, m[i] )
      }
      printf( "junk %u\n", m[i] )
    }
  ' >${d}/${c}.counts
  i3window -clp -cls -avg ${wdgopt} -s ${MOTIFSIZE} -d ${SAMPFACT} ${CLS}.i3d ${d} ${d}/${d}.img
  c=0
  unset nx ny nz ox oy oz
  eval $( i3stat -sh -s -o ${d}/${d}.img )
  while [ ${c} -lt ${nc} ]; do
    f=$( printf '%03u-%03u' ${nc} ${c} )
    i3cut -fmt MRC -s ${nx} ${ny} ${nz} 1 -o ${ox} ${oy} ${oz} ${c} ${d}/${d}.img ${d}/${f}.avg
    set +e; let c=c+1; set -e
  done
  if [ -r ${CLS}.cls ]; then
    cd ${d}
    f=$( printf 'dendr-%03d' ${nc} )
    dendrogram.sh ../${CLS}.cls 1 1.294 ${nc} CL |
    tee ${f}.plt |
    plot -T ps >${f}.ps
    awk '
      /^Tct[0-9]*$/ {
        printf("%03d key %d\n",substr($0,4,length($0)),i++)
      }
    ' ${f}.plt |
    sort -nr -k 3 |
    awk '
      { print substr($0,1,index($0,"key")-2) }
    ' >${f}.seq
    if [ ! ${DIM} = 2 -a m${CLSMONT2D} = mtrue ]; then
      set +e
      classmontage.sh ${nc} .avg ${mont} ${f}.seq
      classmontage.sh ${nc} .avg ${mont}
      set -e
    fi
    cd ..
  fi
# keep *.avg until i3select.sh is adapted
# rm -f *.avg
  if [ ${CLSMONT} ]; then
    if [ ${DIM} = 3 ]; then
      apo=0.05
      i3concat -dim 4 ${d}/???-???.avg ${d}-stk.img
      i3fourier ${d}-stk.img ${d}-stk.fou
      i3mask -md ${CLSMONT} ${CLSMONT} ${CLSMONT} -ms ${apo} ${apo} ${apo} ${d}-stk.fou
      i3fourier -inv ${d}-stk.fou ${d}-stk.img
      rm -f ${d}-stk.fou
      if [ y${YPERM} = ytrue ]; then
        i3montage3d.sh ${d}-stk.img ${d}-mont.img ${d}-y-mont.img
      else
        i3montage3d.sh ${d}-stk.img ${d}-mont.img
      fi
      rm -f ${d}-stk.img
    fi
  fi
done
