#!/bin/bash

set -e

# msa stack file
msastack="${1}"

# prefix
prfx="${2}"

# number of factors
msafact="${3}"

# temp files for MSA
imagic_tmp="${4}"

# imagic input file
imagic_input="imagic-input"

# imagic output and stderr
imagic_output="imagic-output"

# nodefile
if [ ! ${I3NODEFILE} ]; then
  I3NODEFILE=${PBS_NODEFILE}
fi

# number of processors to use
if [ -e ${run}/run/i3.proc ]; then
  processors=$( cat ${run}/run/i3.proc )
else
  processors=1
fi

if [ ${processors} = 1 ]; then
  echo NO >${imagic_input}
else
  echo YES >${imagic_input}
  echo ${processors} >>${imagic_input}
  if [ ${imagic_tmp} ]; then
    echo DEFINE_LOCAL_FILES >>${imagic_input}
    echo ${imagic_tmp} >>${imagic_input}
  else
    echo NO_LOCAL_FILES >>${imagic_input}
  fi
fi

cat >>${imagic_input} <<EOF 
FRESH_MSA
MODULATION
${msastack}
${prfx}-mask
${prfx}-eigenim
yes
50
${msafact}
${prfx}-results
EOF

if [ ${processors} = 1 ]; then

  export IMAGIC_BATCH=1
  echo "! "
  echo "! IMAGIC program: msa ------------------------------------------------"
  echo "! "
  ${IMAGIC_ROOT}/msa/msa.e <${imagic_input}
  echo "! "
  echo "! END: msa --------------------------------------------------"
  echo "! "

else

  export IMAGIC_BATCH=1
  echo "! "
  echo "! IMAGIC program: msa(mpi) ------------------------------------------------"
  echo "! "
  mpirun --mca btl_tcp_if_exclude lo,eth1 -np ${processors} -hostfile ${I3NODEFILE} -x IMAGIC_BATCH ${IMAGIC_ROOT}/msa/msa.e_mpi <${imagic_input}
  echo "! "
  echo "! END: msa --------------------------------------------------"
  echo "! "

fi
