#!/bin/bash
#
# i3msastack.sh  version 2.2  extract motifs
#

set -e

# Imagic options
if [ x${USEIMAGIC} = xtrue ]; then
  fmt="-fmt imagic"
  sffx=".hed"
else
  unset fmt
  sffx=".img"
fi

# msa stack file
msastackprfx="${I3TMPDIR:-.}/${PRFX}-msa"
msastack="${msastackprfx}${sffx}"

# msa set
msaset="${SET}-${1}"

# msa mask
msamask="${MSAMASK:-${PRFX}-msamask.img}"

# check if msamask exists
if [ ! -e ${msamask} ]; then
  echo "$( basename $0 ): MSA mask not found" >&2; exit 1
fi

# msa mask and window size
unset nx ny nz
eval $( i3stat -sh -s ${msamask} )
msamasksize="${nx} ${ny} ${nz}"
if [ "${MSAPOLSIZE}" ]; then
  msawinsize="${MSAIMGSIZE}"
else
  msawinsize="${msamasksize}"
fi

# options for mask and filter
unset imgmsk
if [ "${MSAIMGMSK}" ]; then
  imgmsk="${MSAIMGMSK}"
fi
unset filt
if [ "${MSALOWPASS}" ]; then
  filt="${filt} -lp ${MSALOWPASS}"
  if [ "${MSALOWAPO}" ]; then
    filt="${filt} -ls ${MSALOWAPO}"
  fi
fi
if [ "${MSAHIPASS}" ]; then
  filt="${filt} -hp ${MSAHIPASS}"
  if [ "${MSAHIAPO}" ]; then
    filt="${filt} -hs ${MSAHIAPO}"
  fi
fi

# averages
if [ x${MSAIMGAVG} = xtrue ]; then
  stk="${msastackprfx}-stk"
  i3window -clp -s ${msawinsize} -d ${MSAIMGSMP} ${I3D} ${msaset} ${stk}.img
  i3avg ${stk}.img ${stk}.avg ${stk}.var
  i3fourier ${stk}.avg ${stk}.avg.fou
  i3compute ${stk}.avg.mod = abs ${stk}.avg.fou
  i3fourier ${stk}.img  ${stk}.fou
  i3avg -mod ${stk}.fou ${stk}.mod.avg
  i3compute ${stk}.mod.0 = ${stk}.mod.avg eq 0
  i3compute ${stk}.mod.div = ${stk}.mod.avg + ${stk}.mod.0
  i3compute ${stk}-Q.img = ${stk}.avg.mod / ${stk}.mod.div
  rm -f ${stk}.avg.mod ${stk}.mod.div ${stk}.mod.0
  rm -f ${stk}.avg.fou
  rm -f ${stk}.fou
  if [ ! x${MSAIMGKEEP} = xtrue ]; then
   rm -f ${stk}.img
  fi
fi

# extract masked and filtered motifs
i3window ${fmt} -clp -s ${msawinsize} -mean ${imgmsk} -d ${MSAIMGSMP} ${filt} ${I3D} ${msaset} ${msastack}

# additional filter
if [ ! x${MSAFILT} = x ]; then
  i3fourier ${msastack} ${msastack}.fou
  i3compute ${msastack}.fou \* ${MSAFILT}
  i3fourier ${fmt} -inv ${msastack}.fou ${msastack}
  rm -f ${msastack}.fou
fi

# convert to polar
if [ "${MSAPOLSIZE}" ]; then
  if [ "${MSAPOLSIZE}" = auto ]; then
    msapolsize="$( i3polsize.sh ${MSAIMGSIZE} )"
  else
    msapolsize="${MSAPOLSIZE}"
  fi
  i3polar -s ${msapolsize} ${msastack} ${msastack}.pol
  mv -f ${msastack}.pol ${msastack}
fi

# export transformations
if [ x${USEIMAGIC} = xtrue ]; then
  i3datalist ${I3D} ${msaset} >${PRFX}-msa.trf
fi
