#!/bin/bash
#
# i3select.sh  version 2.2  prepare images for alignment of class averages
#

set -e

# set input file paths

dir="${SEL}"

export I3FILEPATH=".:${dir}"


# check

[ ! -d ${dir} ] && { echo "$( basename $0 ): ${dir} does not exist or is not a directory" >&2; exit 1; }


# create mask

i3new -c -s ${MOTIFSIZE} -val 1 ${SEL}-mask.img

[ "${SELMSKOPT1}" ] && i3mask ${SELMSKOPT1} ${SEL}-mask.img
[ "${SELMSKOPT2}" ] && i3mask ${SELMSKOPT2} ${SEL}-mask.img
[ "${SELMSKOPT3}" ] && i3mask ${SELMSKOPT3} ${SEL}-mask.img


# define maps and data subsets

i3d="${SEL}.i3d"

i3create ${i3d}

echo -n >${dir}/ref.trf

for c in ${dir}/*.avg; do

  d=$( basename ${c} .avg )
  e=${dir}/${d}

  i3fourier -zm ${c} ${e}.fou

  i3mask -md ${SELLOWPASS} -ms ${SELLOWAPO} ${e}.fou

  i3mask -minv -md ${SELHIPASS} -ms ${SELHIAPO} ${e}.fou

  if [ ! x${SELFILT} = x ]; then
    i3compute ${e}.fou \* ${SELFILT}
  fi

  i3fourier -inv -c ${e}.fou ${e}.img

  i3compute ${e}.img \* ${SEL}-mask.img

  i3compute ${e}.img -mean

  i3compute ${e}.img /rms

  i3fourier -zm ${e}.img ${e}.fou

  i3external ${i3d} ${d}.img

  if [ ${DIM} = 2 ]; then
    echo "0 0" |
    i3boximport ${i3d} ${d}.img - box-${d}
    echo "box-${d}  0 0  0 0  1 0  0 1" >>${dir}/ref.trf
  else 
    echo "0 0 0" |
    i3boximport ${i3d} ${d}.img - box-${d}
    echo "box-${d}  0 0 0  0 0 0  1 0 0  0 1 0  0 0 1" >>${dir}/ref.trf
  fi

done

for c in ${dir}/*.avg; do

  d=$( basename ${c} .avg )

  i3external ${i3d} ${d}.avg

  if [ ${DIM} = 2 ]; then
    echo "0 0" |
    i3boximport ${i3d} ${d}.avg - box-${d}-avg
  else 
    echo "0 0 0" |
    i3boximport ${i3d} ${d}.avg - box-${d}-avg
  fi

done

for c in ${dir}/*.img; do

  d=$( basename ${c} .img )

  grep -v ^box-${d} ${dir}/ref.trf |
  i3dataimport -dim ${DIM} ${i3d} ref-${d} -

done

awk -v d=${DIM} '
  BEGIN { n = 0 }
  /^box/ { b[n++] = substr( $1, 5 ) }
  END {
    for ( i = 0; i < n - 1; i++ ) {
      for ( j = i + 1; j < n; j++ ) {
        if ( d == 2 ) {
          print "ref-" b[i], "box-" b[j], "0 0  0 0  1 0  0 1"
        } else {
          print "ref-" b[i], "box-" b[j], "0 0 0  0 0 0  1 0 0  0 1 0  0 0 1"
        }
      }
    }
  }
' ${dir}/ref.trf |
while read r b t; do
  echo "${t}" | i3dataset ${i3d} ${r}-${b} ${b} -
done

awk '{ b = $1; sub( "^box", "ref", b ); print b, $0 }' ${dir}/ref.trf |
while read box trf; do
  echo ${trf} |
  i3dataimport -dim ${DIM} ${i3d} ${box}-single -
done


# create montages of the filtered images

if [ x${SELMONTINI} = xtrue ]; then

  i3concat -dim 4 ${dir}/*.img ${SEL}-tmp.img

  i3montage -col ${SELMONTCOL:-10} ${SEL}-tmp.img ${SEL}-mont.img

  if [ ${DIM} = 3 -a y${YPERM} = ytrue ]; then
    i3permute -perm 1 0 0 0 0 1 0 -1 0 ${SEL}-tmp.img ${SEL}-y.img
    i3montage -col ${SELMONTCOL:-10} ${SEL}-y.img ${SEL}-y-mont.img
    rm -f ${SEL}-y.img
  fi

  rm -f ${SEL}-tmp.img

fi
