#!/bin/bash
#
# i3selectalignsinglemake.sh  version 2.2  create individual alignment scripts
#

[ $# -lt 1 ] && { echo "usage: $( basename $0 ) mode [params]" >&2; exit 1; }

set -e

# exec mode (nohup or submit.sh etc.)
mode=${1}
shift

# script directory
exe="i3selectalignsingle"


# parameters

if [ ${DIM} = 3 ]; then
  srch="-se"
else
  srch="-sr"
fi

unset cmr
if [ "${SELCMR}" ]; then
  cmr=" -cmr ${SELCMR}"
fi


# set input file paths

dir="${SEL}"

export I3FILEPATH=".:${dir}"

# create shell scripts

mkdir ${exe}

echo -n >${exe}run.sh

i3contents ${SEL}.i3d 2>&1 |
awk ' /ref-[0-9]+-[0-9]+ / { sub( "ref-", "", $2 ); if ( !r ) r = $2; print r, $2 } ' |
while read ref box; do
  set -e
  f="${exe}/ref-${box}"
  {
    echo '#!/bin/bash'
    echo 'set -e'
    echo "sel=${SEL}"
    if [ ${SELREFIMG} ]; then
      echo "ref=${SELREFIMG}"
    else
      echo "ref=${ref}.fou"
    fi
    echo "box=${box}"
    echo 'dir=${sel}'
    echo 'export I3FILEPATH=".:${dir}"'
    echo 'echo start at $( date ) >&2'
    echo 'set=ref-${box}-single'
    echo 'i3d=${dir}/${set}.i3d'
    echo 'cp ${sel}.i3d ${i3d}'
    echo "i3align -log -cc ${SELCC:-xcf} -pkr ${SELPKR}${cmr} ${srch} ${SELSRCH}" '${ref} ${i3d} ${set} ${set}-aligned'
    echo 'i3datalist ${i3d} ${set}-aligned >${dir}/${set}.trf'
    echo 'rm -f ${i3d}'
    echo 'echo normal end at $( date ) >&2'
  } >${f}.sh
  chmod +x ${f}.sh
  case "${mode}" in
    nohup) echo "nohup ${f}.sh >${f}.log 2>&1" >>${exe}run.sh ;;
    cobra) echo "${I3COBRA:-custom.sh} ${f}.sh ${f}.log" >>${exe}run.sh ;;
    *)     echo "submit.sh ${f}.sh logfile=${f}.log $*" >>${exe}run.sh ;;
  esac
done
if [ "${mode}" = nohup ]; then
  if [ ${1} ]; then
    awk -v w=${1} '
      BEGIN { i = w }
      { print $0, "&"; i-- }
      w > 0 && !i { print "wait"; i = w }
      END { if ( w <= 0 || i < w ) { print "wait" } }
    ' ${exe}run.sh >${exe}runtmp.sh
    mv -f ${exe}runtmp.sh ${exe}run.sh
  fi
fi
